@@ -1,7 +1,7 @@
 // @ts-check
 import { dirname } from 'path';
 
-import { RollupOptions } from 'rollup';
+import type { RollupOptions } from 'rollup';
 
 import replace from '..';
 
